# -*- rpm-spec -*-

# This macro is used for the continuous automated builds. It just
# allows an extra fragment based on the timestamp to be appended
# to the release. This distinguishes automated builds, from formal
# Fedora RPM builds
%define _extra_release %{?dist:%{dist}}%{!?dist:%{?extra_release:%{extra_release}}}

Summary: Library providing a simple API for virtualization
Name: libvirt
Version: 0.2.3
Release: 9%{?_extra_release}
License: LGPL
Group: Development/Libraries
Source: libvirt-%{version}.tar.gz
Source1: libvirtd
BuildRoot: %{_tmppath}/%{name}-%{version}-root
URL: http://libvirt.org/
BuildRequires: python python-devel
Requires: xen
Requires: libxml2
Requires: readline
Requires: ncurses
Requires: dnsmasq
BuildRequires: xen-devel
BuildRequires: libxml2-devel
BuildRequires: readline-devel
BuildRequires: ncurses-devel
BuildRequires: gettext
BuildRequires: libsysfs-devel
BuildRequires: /sbin/iptables
Obsoletes: libvir
ExclusiveArch: i386 x86_64 ia64
Patch0:libvirt-0.2.2-pvfb-new-config.patch
Patch1:attach_detach_opt.patch
Patch2:libvirt-0.2.3-connleak.patch
Patch3:libvirt-0.2.3-pvfb-config.patch
Patch4:libvirt-0.2.3-virt-network.patch
Patch5:libvirt-0.2.3-proxy-uuid.patch
Patch6:libvirt-0.2.3-update-man-page.patch
Patch7:libvirt-0.2.3-pvfb-xml.patch

%description
Libvirt is a C toolkit to interract with the virtualization capabilities
of recent versions of Linux (and other OSes).

%package devel
Summary: Libraries, includes, etc. to compile with the libvirt library
Group: Development/Libraries
Requires: libvirt = %{version}
Requires: pkgconfig
Obsoletes: libvir-devel

%description devel
Includes and documentations for the C library providing an API to use
the virtualization capabilities of recent versions of Linux (and other OSes).

%package python
Summary: Python bindings for the libvirt library
Group: Development/Libraries
Requires: libvirt = %{version}
Obsoletes: libvir-python

%description python
The libvirt-python package contains a module that permits applications
written in the Python programming language to use the interface
supplied by the libvirt library to use the the virtualization capabilities 
of recent versions of Linux (and other OSes).

%prep
%setup -q
%patch0 -p1
%patch1 -p0
%patch2 -p0
%patch3 -p1
%patch4 -p1
%patch5 -p0
%patch6 -p1
%patch7 -p1

%build
%configure --with-init-script=redhat --with-qemud-pid-file=%{_localstatedir}/run/libvirt_qemud.pid
make

%install
rm -fr %{buildroot}

%makeinstall
(cd docs/examples ; make clean ; rm -rf .deps Makefile Makefile.in)
(cd docs/examples/python ; rm -f Makefile Makefile.in)

rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/python*/site-packages/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/python*/site-packages/*.a
install -d -m 0755 $RPM_BUILD_ROOT%{_localstatedir}/run/libvirt/

# We don't want to install /etc/libvirt/qemu/networks in the main %files list
# because if the admin wants to delete the default network completely, we don't
# want to end up re-incarnating it on every RPM upgrade.
install -d -m 0755 $RPM_BUILD_ROOT%{_sysconfdir}/rc.d/init.d/
install -m 0755 %SOURCE1 $RPM_BUILD_ROOT%{_sysconfdir}/rc.d/init.d/
install -d -m 0755 $RPM_BUILD_ROOT%{_datadir}/libvirt/networks/
cp $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu/networks/default.xml \
   $RPM_BUILD_ROOT%{_datadir}/libvirt/networks/default.xml
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu/networks/default.xml
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu/networks/autostart/default.xml
# Strip auto-generated UUID - we need it generated per-install
sed -i -e "/<uuid>/d" $RPM_BUILD_ROOT%{_datadir}/libvirt/networks/default.xml
%find_lang %{name}

%clean
rm -fr %{buildroot}

%post
/sbin/ldconfig

# We want to install the default network for initial RPM installs
# or on the first upgrade from a non-network aware libvirt only.
# We check this by looking to see if the daemon is already installed
/sbin/chkconfig --list libvirtd 1>/dev/null 2>&1
if [ $? != 0 ]
then
    UUID=`/usr/bin/uuidgen`
    sed -e "s,</name>,</name>\n  <uuid>$UUID</uuid>," \
         < %{_datadir}/libvirt/networks/default.xml \
         > %{_sysconfdir}/libvirt/qemu/networks/default.xml
    ln -s ../default.xml %{_sysconfdir}/libvirt/qemu/networks/autostart/default.xml
fi

/sbin/chkconfig --add libvirtd

%preun
if [ $1 = 0 ]; then
    /sbin/service libvirtd stop 1>/dev/null 2>&1
    /sbin/chkconfig --del libvirtd
fi

%postun
/sbin/ldconfig

%files -f %{name}.lang
%defattr(-, root, root)

%doc AUTHORS ChangeLog NEWS README COPYING.LIB TODO
%doc %{_mandir}/man1/virsh.1*
%{_bindir}/virsh
%{_libdir}/lib*.so.*
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/networks/
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/networks/autostart
%{_sysconfdir}/rc.d/init.d/libvirtd
%dir %{_sysconfdir}/libvirt
%dir %{_sysconfdir}/libvirt/qemu
%dir %{_sysconfdir}/libvirt/qemu/networks
%dir %{_sysconfdir}/libvirt/qemu/networks/autostart
%dir %{_datadir}/libvirt/
%dir %{_datadir}/libvirt/networks/
%{_datadir}/libvirt/networks/default.xml
%dir %{_localstatedir}/run/libvirt/
%dir %{_localstatedir}/lib/libvirt/
%attr(4755, root, root) %{_libexecdir}/libvirt_proxy
%attr(0755, root, root) %{_sbindir}/libvirt_qemud
%doc docs/libvirt.rng

%files devel
%defattr(-, root, root)

%{_libdir}/lib*.so
%dir %{_includedir}/libvirt
%{_includedir}/libvirt/*.h
%{_libdir}/pkgconfig/libvirt.pc
%doc %{_datadir}/gtk-doc/html/libvirt/*.devhelp
%doc %{_datadir}/gtk-doc/html/libvirt/*.html
%doc %{_datadir}/gtk-doc/html/libvirt/*.png
%doc %{_datadir}/gtk-doc/html/libvirt/*.css

%doc docs/*.html docs/html docs/*.gif
%doc docs/examples
%doc docs/libvirt-api.xml

%files python
%defattr(-, root, root)

%doc AUTHORS NEWS README COPYING.LIB
%{_libdir}/python*/site-packages/libvirt.py*
%{_libdir}/python*/site-packages/libvirtmod*
%doc python/tests/*.py
%doc python/TODO
%doc python/libvirtclass.txt
%doc docs/examples/python

%changelog
* Sat Nov 17 2007 Eddy Nigg <eddy_nigg@startcom.org>
- Rebuild for StartCom Linux 5.0.x

* Tue Aug 28 2007 Daniel Veillard <veillard@redhat.com> - 0.2.3-9.el5
- patch to fix the pvfb vncdisplay port in XML dumps
- Resolves: rhbz #254188
- Related: rhbz #250789

* Fri Aug 17 2007 Hugh O. Brock <hbrock@redhat.com> - 0.2.3-8.el5
- Overhaul man page to accurately reflect the available commands
- Resolves: rhbz #253013

* Tue Aug 14 2007 Daniel Veillard <veillard@redhat.com> - 0.2.3-7.el5
- Fix UUID lookup though proxy (i.e. as user)
- Resolves: rhbg#224415

* Mon Aug 13 2007 Daniel Veillard <veillard@redhat.com> - 0.2.3-6.el5
- Fix handling of PVFB configurations
- Resolves: rhbg#250789
- Fix config file when using virtual network
- Resolves: rhbg#251594

* Tue Jul 31 2007 Daniel Veillard <veillard@redhat.com> - 0.2.3-5.el5
- Fix a leak when closing a connection
- Resolves: rhbg#250146

* Wed Jun 27 2007 Daniel Berrange <berrange@redhat.com> - 0.2.3-4.el5
- Re-add multilib fix from 0.1.8-14.el5 accidentally lost in 0.2.3-1.el5
- Related: rhbz#243463

* Tue Jun 19 2007 Daniel Veillard <veillard@redhat.com> 0.2.3-3.el5
- add new, more convenient commands for device attach and detach in virsh
- Resolves: rhbz#234840

* Tue Jun 19 2007 Daniel Veillard <veillard@redhat.com> 0.2.3-2.el5
- add Requires: dnsmasq
- Resolves: rhbz#244247

* Thu Jun 14 2007 Daniel Veillard <veillard@redhat.com> 0.2.3-1.el5
- Upgrade to version 0.2.3 for RHEL-5.1
- Resolves: rhbz#243463
- Resolves: rhbz#222704
- Resolves: rhbz#224415
- Resolves: rhbz#225566
- Resolves: rhbz#225567
- Resolves: rhbz#229176
- Note: 0.2.3 is really supposed to work with dnsmask which is not 
  available at the moment in RHEL-5

* Thu Jan 25 2007 Daniel Berrange <berrange@redhat.com> 0.1.8-15.el5
- re-do the localization patch, so that we don't have to run
  'make update-po', and thus avoid multilib conflicts
- Resolves: rhbz#224446

* Thu Jan 25 2007 Daniel Berrange <berrange@redhat.com> 0.1.8-14.el5
- further fix for parallel installation problem of -devel on i386 and x86_64
- Resolves: rhbz#222730

* Thu Jan 18 2007 Daniel Veillard <veillard@redhat.com> 0.1.8-13.el5
- last update of localization for RHEL languages
- Resolves: rhbz#203726 	

* Thu Dec 21 2006 Daniel Veillard <veillard@redhat.com> 0.1.8-12.el5
- fix a parallel installation problem of -devel on i386 and x86_64
- Resolves: rhbz#222730

* Thu Dec 21 2006 Daniel Veillard <veillard@redhat.com> 0.1.8-11.el5
- updates localization for RHEL languages
- Related: rhbz#203726 	

* Wed Dec 13 2006 Daniel Veillard <veillard@redhat.com> 0.1.8-10.el5
- fix the maxid array overflow when listing domains, rhbz#218789
- Resolves: rhbz#218789

* Wed Dec 13 2006 Daniel Veillard <veillard@redhat.com> 0.1.8-9.el5
- Add the two pvfb patches, rhbz#218486
- Resolves: rhbz#218486

* Thu Dec  7 2006 Daniel Veillard <veillard@redhat.com> 0.1.8-8.el5
- fix a structure error when asking the hypervisor for vcpu info, rhbz#217743
  and rhbz#217370
- Resolves: rhbz#217370 rhbz#217743

* Thu Dec  7 2006 Daniel Veillard <veillard@redhat.com> 0.1.8-7.el5
- release python global interpreter lock when calling libvirt, rhbz#210140
- return correct os type version for HVM guests when running as non-root, 
  rhbz#214264
- Resolves: rhbz#210140 rhbz#214264

* Thu Dec  7 2006 Daniel Veillard <veillard@redhat.com> 0.1.8-6.el5
- save the amount of current memory used when dumping XML if different from
  maximum amount, and use that when restarting the domain from the XML,
  rhbz#214354
- when using a pygrub bootloader, strip the os informations because xend
  assumes they take precedence over bootloader, rhbz#214741
- Resolves: rhbz#214354 rhbz#214741

* Thu Dec  7 2006 Daniel Veillard <veillard@redhat.com> 0.1.8-5.el5
- patch adding a domain core dump entry point to the library, it requires
  xen >= 3_0_3-13_el5 to get the xend server side support
- Resolves: rhbz#214913

* Mon Dec  4 2006 Daniel Veillard <veillard@redhat.com> 0.1.8-4.el5
- add localization updates for RHEL languages
- Resolves: rhbz#203726 	

* Mon Dec  4 2006 Daniel Veillard <veillard@redhat.com> 0.1.8-3.el5
- add support for shareable disks
- Resolves: rhbz#214908

* Tue Oct 31 2006 Daniel Veillard <veillard@redhat.com> 0.1.8-2.el5
- avoid Xend 404 GET error message when listing non-existent domain
- Resolves: rhbz#207166

* Mon Oct 16 2006 Daniel Veillard <veillard@redhat.com> 0.1.8-1.el5
- another ia64 page size fix
- vcpu number initialization
- don't label crashed domains as shut off
- fix virsh man page
- compile fix

* Sat Oct  7 2006 Daniel P. Berrange <berrange@redhat.com> 0.1.7-3.el5
- add new <driver> element to support blktap backed disks

* Mon Oct  2 2006 Daniel Veillard <veillard@redhat.com> 0.1.7-2
- fix missing page size detection code for ia64
- fix mlock size when getting domain info list from hypervisor

* Fri Sep 22 2006 Daniel Veillard <veillard@redhat.com> 0.1.7-1
- Fix bug when running against xen-3.0.3 hypercalls
- Fix memory bug when getting vcpus info from xend

* Fri Sep 22 2006 Daniel Veillard <veillard@redhat.com> 0.1.6-1
- Support for localization
- Support for new Xen-3.0.3 cdrom and disk configuration
- Support for setting VNC port
- Fix bug when running against xen-3.0.2 hypercalls
- Fix reconnection problem when talking directly to http xend

* Tue Sep  5 2006 Jeremy Katz <katzj@redhat.com> - 0.1.5-3
- patch from danpb to support new-format cd devices for HVM guests

* Tue Sep  5 2006 Daniel Veillard <veillard@redhat.com> 0.1.5-2
- reactivating ia64 support

* Tue Sep  5 2006 Daniel Veillard <veillard@redhat.com> 0.1.5-1
- new release
- bug fixes
- support for new hypervisor calls
- early code for config files and defined domains

* Mon Sep  4 2006 Daniel Berrange <berrange@redhat.com> - 0.1.4-5
- add patch to address dom0_ops API breakage in Xen 3.0.3 tree

* Mon Aug 28 2006 Jeremy Katz <katzj@redhat.com> - 0.1.4-4
- add patch to support paravirt framebuffer in Xen 

* Mon Aug 21 2006 Daniel Veillard <veillard@redhat.com> 0.1.4-3
- another patch to fix network handling in non-HVM guests

* Thu Aug 17 2006 Daniel Veillard <veillard@redhat.com> 0.1.4-2
- patch to fix virParseUUID()

* Wed Aug 16 2006 Daniel Veillard <veillard@redhat.com> 0.1.4-1
- vCPUs and affinity support
- more complete XML, console and boot options
- specific features support
- enforced read-only connections
- various improvements, bug fixes

* Wed Aug  2 2006 Jeremy Katz <katzj@redhat.com> - 0.1.3-6
- add patch from pvetere to allow getting uuid from libvirt

* Wed Aug  2 2006 Jeremy Katz <katzj@redhat.com> - 0.1.3-5
- build on ia64 now

* Thu Jul 27 2006 Jeremy Katz <katzj@redhat.com> - 0.1.3-4
- don't BR xen, we just need xen-devel

* Thu Jul 27 2006 Daniel Veillard <veillard@redhat.com> 0.1.3-3
- need rebuild since libxenstore is now versionned

* Mon Jul 24 2006 Mark McLoughlin <markmc@redhat.com> - 0.1.3-2
- Add BuildRequires: xen-devel

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 0.1.3-1.1
- rebuild

* Tue Jul 11 2006 Daniel Veillard <veillard@redhat.com> 0.1.3-1
- support for HVM Xen guests
- various bugfixes

* Mon Jul  3 2006 Daniel Veillard <veillard@redhat.com> 0.1.2-1
- added a proxy mechanism for read only access using httpu
- fixed header includes paths

* Wed Jun 21 2006 Daniel Veillard <veillard@redhat.com> 0.1.1-1
- extend and cleanup the driver infrastructure and code
- python examples
- extend uuid support
- bug fixes, buffer handling cleanups
- support for new Xen hypervisor API
- test driver for unit testing
- virsh --conect argument

* Mon Apr 10 2006 Daniel Veillard <veillard@redhat.com> 0.1.0-1
- various fixes
- new APIs: for Node information and Reboot
- virsh improvements and extensions
- documentation updates and man page
- enhancement and fixes of the XML description format

* Tue Feb 28 2006 Daniel Veillard <veillard@redhat.com> 0.0.6-1
- added error handling APIs
- small bug fixes
- improve python bindings
- augment documentation and regression tests

* Thu Feb 23 2006 Daniel Veillard <veillard@redhat.com> 0.0.5-1
- new domain creation API
- new UUID based APIs
- more tests, documentation, devhelp
- bug fixes

* Fri Feb 10 2006 Daniel Veillard <veillard@redhat.com> 0.0.4-1
- fixes some problems in 0.0.3 due to the change of names

* Wed Feb  8 2006 Daniel Veillard <veillard@redhat.com> 0.0.3-1
- changed library name to libvirt from libvir, complete and test the python 
  bindings

* Sun Jan 29 2006 Daniel Veillard <veillard@redhat.com> 0.0.2-1
- upstream release of 0.0.2, use xend, save and restore added, python bindings
  fixed

* Wed Nov  2 2005 Daniel Veillard <veillard@redhat.com> 0.0.1-1
- created
